fedex.base_service

Package fedex :: Module base_service |
[hide private]
[frames] | no frames]

# Module base_service

source code

The base_service module contains classes that form the low level foundations of the Web Service API. Things that many different kinds of requests have in common may be found here.

In particular, the FedexBaseService class handles most of the basic, repetetive setup work that most requests do.

Classes | [hide private]
| FedexBaseServiceException Exception: Serves as the base exception that other service-related exception objects are sub-classed from.
| FedexFailure Exception: The request could not be handled at this time.
| FedexError Exception: These are generally problems with the client-provided data.
| SchemaValidationError Exception: There is probably a problem in the data you provided.
| FedexBaseService This class is the master class for all Fedex request objects.

Variables | [hide private]
| __package__ = ``'``fedex``'``